#!/usr/bin/env python3

import matplotlib.pyplot as plt
import numpy as np

import lib

seed = 12345
dt = 1 # ns
t = np.arange(0, 10*int(1e3), dt)
frequency = 45e-3 # GHz

N = 5e2
rng = np.random.default_rng(seed)

phase_res = np.zeros(int(N))

for i in range(int(N)):
    phase = lib.phase_mod(np.pi*(2*rng.uniform(size=1) -1)) # rad
    beacon = lib.sine_beacon(frequency, t, t0=0, phase=phase)

    measured = lib.find_beacon_in_traces([beacon], t, frequency, frequency_fit=False)

    phase_res[i] = lib.phase_mod(measured[1][0] - phase)

fig, ax = plt.subplots()
ax.set_xlabel("$\\varphi_{meas} - \\varphi_{true}$ [rad]")
ax.set_ylabel("#")
ax.hist(phase_res, bins='sqrt')
plt.show()
